function FC_TAC_TALF_plots()

%%% This function reads "FC_mlydata.csv" and "TACTALF_Hamilton2014.csv", and reproduces figure 5 in the forthcoming version of Lai & Ye (2019)  

close all

banksumtable = readtable('../data/FC_mlydata.csv');

BankSum = banksumtable.FC_allbanks/1000;
dateVector = banksumtable.Dates;

startdate = 200201;
enddate = 201007;

TACTALF = readtable('../data/TACTALF_Hamilton2014.csv');

[~, mthselector] = unique(year(TACTALF.Date)*100 + month(TACTALF.Date), 'last');

TACTALF = TACTALF(mthselector, :);

selector_tactalf = year(TACTALF.Date)*100 + month(TACTALF.Date) <= enddate;

TACTALF = TACTALF(selector_tactalf, :);


selector = (year(dateVector)*100 + month(dateVector) >= startdate & year(dateVector)*100 + month(dateVector) < enddate);

set(gcf, 'Position', [10 10 1450/1.6 680/1.4]*0.75)
set(gcf, 'Color', 'w');

dateinplot = datetime(datestr(dateVector(selector)));
fcinplot = BankSum(selector);

tactalfdatesinplot = TACTALF.Date(2:end);
tactalfinplot = [diff(TACTALF.TAC).*(diff(TACTALF.TAC)>0) diff(TACTALF.TALF).*(diff(TACTALF.TALF)>0)];

yyaxis left
plot(dateinplot, fcinplot, 'k-.', 'LineWidth',1.3)
ylabel('{\bf{FC}} in B\$', 'Interpreter', 'latex')

yyaxis right
hold on
b1 = bar(tactalfdatesinplot, tactalfinplot, 1, 'stacked');

b1(1).LineWidth = 0.01;
b1(1).EdgeColor = [0.4 0.4 0.4];
b1(1).FaceColor = [0.5 0.5 0.5];

b1(2).LineWidth = 0.01;
b1(2).EdgeColor = [0.2 0.2 0.2];
b1(2).FaceColor = [0.3 0.3 0.3];

hold off
ylabel('TAC/TALF capital in B\$', 'Interpreter', 'latex')
legend({'{\bf{FC}} from all banks (left y-axis)', 'TAF capitals (right y-axis)', 'TALF capitals (right y-axis)'}, 'Location','NorthWest', 'Interpreter', 'latex')


legend('boxoff')
box off
grid on

%%%%%%%%%%%%%%%%

startdate = 200706;
enddate = 201106;

figure

set(gcf, 'Position', [10 10 1450/1.6 680/1.4]*0.75)
set(gcf, 'Color', 'w');

TACTALF = readtable('../data/TACTALF_Hamilton2014.csv');

selector_tactalf = year(TACTALF.Date)*100 + month(TACTALF.Date) <= enddate;
TACTALF = TACTALF(selector_tactalf, :);

selector = (year(dateVector)*100 + month(dateVector) >= startdate & year(dateVector)*100 + month(dateVector) < enddate);
dateinplot0 = datetime(datestr(dateVector(selector)));
fcinplot0 = BankSum(selector);

TACTALF4plot = TACTALF;

dateinplot = dateinplot0(2:end);
d_fcinplot = diff(fcinplot0);

tactalfdates = TACTALF4plot.Date(2:end);
yyyymm = year(tactalfdates)*100 + month(tactalfdates);
d_tactalfinplot = diff(TACTALF4plot.sum);

d_tactalfinplot_mly = zeros(size(dateinplot));

for t = 1:length(d_tactalfinplot_mly)
    selector = (yyyymm == year(dateinplot(t))*100 + month(dateinplot(t)));
    d_tactalfinplot_mly(t) = sum(d_tactalfinplot(selector));
end


hold on
b = bar(dateinplot, d_tactalfinplot_mly, 0.8);
plot(dateinplot, d_fcinplot, 'r', 'LineWidth',1.5)
hold off
b.LineWidth = 0.01;
b.EdgeColor = 'none';

legend({'Change in TAF+TALF capitals', '{Change in \bf{FC}} from all banks'}, 'Location','NorthWest', 'Interpreter', 'latex')
ylabel('Monthly capital change in B\$', 'Interpreter', 'latex')

legend('boxoff')
box off
grid on

end
