function summary_plot(plotstr)

% input plotstr as 'ffc' to reproduce figure 2 in the forthcoming version of Lai & Ye (2019)
% input plotstr as 'fc' to reproduce figure 3 in the forthcoming version of Lai & Ye (2019)
% input plotstr as 'rhostar' to reproduce figure 4 in the forthcoming version of Lai & Ye (2019)

largeBankMdn = table2array(readtable(['../data/large_bank_' plotstr '.csv']));
bigBankMdn = table2array(readtable(['../data/big_bank_' plotstr '.csv']));
midBankMdn = table2array(readtable(['../data/mid_bank_' plotstr '.csv']));
nosmallBankMdn = table2array(readtable(['../data/nosmall_bank_' plotstr '.csv']));
dateVector = table2array(readtable('../data/dateinmatformat.csv'));


plotstr4checking = upper(plotstr);

switch plotstr4checking
    case 'RHOSTAR'
        yliminput = [0.9, 1];
        ytickinput = 0.9:.02:1;
        yliminput1 = [0.6, 1];
        ytickinput1 = 0.6:.1:1;
    case 'FFC'
        yliminput = [0, 1];
        ytickinput = 0:.2:1;
        yliminput1 = yliminput;
        ytickinput1 = ytickinput;
    case 'FC'
        yliminput = [];
        ytickinput = [];
        yliminput1 = yliminput;
        ytickinput1 = ytickinput;
end

close all

set(gcf, 'Position', [10 10 800 1200*2/3])
set(gcf, 'Color', 'w');

prctV = [10,25,50,75,90];
lwV = [0.5; 0.5; 2.4; 0.5];
lsV = {'g--', 'r--', 'k', 'k--'};

minDate = min(dateVector);
maxDate = max(dateVector);

subplot(2,2,1)
hold on
ciplot(largeBankMdn(:,1),largeBankMdn(:,end),dateVector)
ciplot(largeBankMdn(:,2),largeBankMdn(:,end-1),dateVector,[0.5 0.5 0.5])
plot(dateVector,largeBankMdn(:,prctV==50), lsV{3}, 'LineWidth',lwV(3))
ylim_my(yliminput1,ytickinput1)
set(gca,'XLim',[minDate, maxDate]);datetick('x','yy', 'keeplimits','keepticks')
title('Large Banks')
box off
hold off

subplot(2,2,2)
hold on
ciplot(bigBankMdn(:,1),bigBankMdn(:,end),dateVector)
ciplot(bigBankMdn(:,2),bigBankMdn(:,end-1),dateVector,[0.5 0.5 0.5])
plot(dateVector,bigBankMdn(:,prctV==50), lsV{3}, 'LineWidth',lwV(3))
ylim_my(yliminput,ytickinput)
set(gca,'XLim',[minDate, maxDate]);datetick('x','yy', 'keeplimits','keepticks')
title('Big Banks')
box off
hold off


subplot(2,2,3)
hold on
ciplot(midBankMdn(:,1),midBankMdn(:,end),dateVector)
ciplot(midBankMdn(:,2),midBankMdn(:,end-1),dateVector,[0.5 0.5 0.5])
plot(dateVector,midBankMdn(:,prctV==50), lsV{3}, 'LineWidth',lwV(3))
ylim_my(yliminput,ytickinput)
set(gca,'XLim',[minDate, maxDate]);datetick('x','yy', 'keeplimits','keepticks')
title('Medium Banks')
box off
hold off


subplot(2,2,4)
hold on
ciplot(nosmallBankMdn(:,1),nosmallBankMdn(:,end),dateVector)
ciplot(nosmallBankMdn(:,2),nosmallBankMdn(:,end-1),dateVector,[0.5 0.5 0.5])
plot(dateVector,nosmallBankMdn(:,prctV==50), lsV{3}, 'LineWidth',lwV(3))
ylim_my(yliminput,ytickinput)
set(gca,'XLim',[minDate, maxDate]);datetick('x','yy', 'keeplimits','keepticks')
title('All Banks')
box off
hold off

end


function ciplot(lower,upper,x,colour)

if nargin<4
    colour = [0.75 0.75 0.75];
end

if find(size(x)==(max(size(x))))<2
    x=x';
end
if find(size(lower)==(max(size(lower))))<2
    lower=lower';
end
if find(size(upper)==(max(size(upper))))<2
    upper=upper';
end

h = fill([x fliplr(x)],[upper fliplr(lower)],colour);
set(h,'EdgeColor','None');

end

function ylim_my(yliminput, ytickinput)

global forfc

if ~isempty(yliminput)
    ylim(yliminput)
    set(gca,'YTick',ytickinput)
else
    ylim([0, inf])
end

if forfc
    ylabel('B$')
end
end